@@ -3,7 +3,7 @@ from azfs.az_file_client import (
 )
 
 from azfs.az_file_system import AzFileSystem
-
+from azfs.export_decorator import ExportDecorator
 from azfs.utils import BlobPathDecoder
 
 from .table_storage import (
@@ -12,8 +12,8 @@ from .table_storage import (
 )
 
 # comparable tuple
-VERSION = (0, 2, 8)
+VERSION = (0, 2, 9)
 # generate __version__ via VERSION tuple
 __version__ = ".".join(map(str, VERSION))
 
-__all__ = ["AzFileClient", "AzFileSystem", "BlobPathDecoder", "TableStorage", "TableStorageWrapper"]
+__all__ = ["AzFileClient", "AzFileSystem", "BlobPathDecoder", "TableStorage", "TableStorageWrapper", "ExportDecorator"]
